==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/GetBackupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the NetApp account
 * @property backupName The name of the backup
 * @property poolName The name of the capacity pool
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property volumeName The name of the volume
 */
public data class GetBackupPlainArgs(
    public val accountName: String,
    public val backupName: String,
    public val poolName: String,
    public val resourceGroupName: String,
    public val volumeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs =
        com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .backupName(backupName.let({ args0 -> args0 }))
            .poolName(poolName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .volumeName(volumeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBackupPlainArgs].
 */
@PulumiTagMarker
public class GetBackupPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var backupName: String? = null

    private var poolName: String? = null

    private var resourceGroupName: String? = null

    private var volumeName: String? = null

    /**
     * @param value The name of the NetApp account
     */
    @JvmName("hkwrhxugovlguabd")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the backup
     */
    @JvmName("lmorekrbyermslon")
    public suspend fun backupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupName = mapped
    }

    /**
     * @param value The name of the capacity pool
     */
    @JvmName("tnybowgbnlnpkhlw")
    public suspend fun poolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.poolName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("twwrqyimvpgebkaf")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the volume
     */
    @JvmName("wchxdinykrkpuoie")
    public suspend fun volumeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.volumeName = mapped
    }

    internal fun build(): GetBackupPlainArgs = GetBackupPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        backupName = backupName ?: throw PulumiNullFieldException("backupName"),
        poolName = poolName ?: throw PulumiNullFieldException("poolName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        volumeName = volumeName ?: throw PulumiNullFieldException("volumeName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/GetBackupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the NetApp account
 * @property backupName The name of the backup
 * @property poolName The name of the capacity pool
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property volumeName The name of the volume
 */
public data class GetBackupPlainArgs(
    public val accountName: String,
    public val backupName: String,
    public val poolName: String,
    public val resourceGroupName: String,
    public val volumeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs =
        com.pulumi.azurenative.netapp.inputs.GetBackupPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .backupName(backupName.let({ args0 -> args0 }))
            .poolName(poolName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .volumeName(volumeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBackupPlainArgs].
 */
@PulumiTagMarker
public class GetBackupPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var backupName: String? = null

    private var poolName: String? = null

    private var resourceGroupName: String? = null

    private var volumeName: String? = null

    /**
     * @param value The name of the NetApp account
     */
    @JvmName("numlblcdyfuvyvdm")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the backup
     */
    @JvmName("pxssupgkdmnjlxal")
    public suspend fun backupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.backupName = mapped
    }

    /**
     * @param value The name of the capacity pool
     */
    @JvmName("ddodsxsboldyaqbm")
    public suspend fun poolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.poolName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ulbcmnljaatjaxrx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the volume
     */
    @JvmName("nqaaiwtmmfeuahhq")
    public suspend fun volumeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.volumeName = mapped
    }

    internal fun build(): GetBackupPlainArgs = GetBackupPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        backupName = backupName ?: throw PulumiNullFieldException("backupName"),
        poolName = poolName ?: throw PulumiNullFieldException("poolName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        volumeName = volumeName ?: throw PulumiNullFieldException("volumeName"),
    )
}
